# Tembo

<center>
    <img
        src="https://raw.githubusercontent.com/tembo-pages/tembo-core/main/assets/tembo_logo.png"
        width="200px"
    />
</center>

A simple folder organiser for your work notes.
